==> openwind-0.5.0.tar.gz: openwind-0.5.0/README.md <==
# Open Wind Instrument Design

This is the official repository of the  OpenWInD toolbox, a tool for modelization
of wind musical instruments, using one-dimensional Finite Elements Methods.
Our webpage is [here](https://openwind.gitlabpages.inria.fr/web/).

## Installation

In your python [environment](https://docs.python.org/3/library/venv.html) :

```sh
pip install openwind
```

If you want to install from source, instructions can be found [here](https://openwind.gitlabpages.inria.fr/web/docs/involved.html#install-from-source)

## Documentation

You can read the official documentation [here](https://openwind.gitlabpages.inria.fr/web/docs).

## Website

Our website is [here](https://openwind.gitlabpages.inria.fr/web/).

## About

This toolbox stems from the work of team MAGIQUE-3D at [Inria](https://www.inria.fr/).

Feel free to contact the team at [openwind-contact@inria.fr](mailto:openwind-contact@inria.fr)!

#### Note about participating to the project

If you want to get involved and help us developing the openwind toolbox, you will have to create an account on [gitlab.inria.fr](https://gitlab.inria.fr/)

At the moment, following [INRIA's policy](https://gitlab.inria.fr/siteadmin/doc/-/wikis/home#gitlab-accounts), you have to request this access through our team. In order to create your account, we need you to send us your Name, Surname and email address [here](mailto:openwind-contact@inria.fr). We promise we won't use it for anything else than granting you an access as developer to our project.

==> openwind-0.6.1.tar.gz: openwind-0.6.1/README.md <==
# Open Wind Instrument Design

This is the official repository of the  OpenWInD toolbox, a tool for modelization
of wind musical instruments, using one-dimensional Finite Elements Methods.
Our webpage is [here](https://openwind.gitlabpages.inria.fr/web/).

## Installation

In your python [environment](https://docs.python.org/3/library/venv.html) :

```sh
pip install openwind
```

If you want to install from source, instructions can be found [here](https://openwind.gitlabpages.inria.fr/web/docs/quickstart.html#install-from-source)

## Documentation

You can read the official documentation [here](https://openwind.gitlabpages.inria.fr/web/docs).

## Previous versions

If you are interested in early development versions, you can download them from  [our previous repository](https://gitlab.inria.fr/openwind/release/-/releases)

## Website

Our website is [here](https://openwind.gitlabpages.inria.fr/web/).

## About

This toolbox stems from the work of team Makutu at [Inria](https://www.inria.fr/).

Feel free to contact the team at [openwind-contact@inria.fr](mailto:openwind-contact@inria.fr)!

#### Note about participating to the project

If you want to get involved and help us developing the openwind toolbox, you will have to create an account on [gitlab.inria.fr](https://gitlab.inria.fr/)

At the moment, following [INRIA's policy](https://gitlab.inria.fr/siteadmin/doc/-/wikis/home#gitlab-accounts), you have to request this access through our team. In order to create your account, we need you to send us your Name, Surname and email address [here](mailto:openwind-contact@inria.fr). We promise we won't use it for anything else than granting you an access as developer to our project.
